@@ -2,6 +2,8 @@
 if (file.exists("async")) {
   library(testthat)
   library(pkgcache)
+  print(sessioninfo::package_info("pkgcache", dependencies = TRUE))
+
   test <- function() {
     package <- "pkgcache"
     env_test <- asNamespace("testthat")$env_test
@@ -14,7 +16,7 @@ if (file.exists("async")) {
     test_path <- "async"
     asNamespace("testthat")$test_package_dir(
       package = package, test_path = test_path,
-      filter = NULL, reporter = "check")
+      filter = NULL, reporter = "summary")
   }
   test()
 }
